<?php
// include the menu_lib.php file within this script
require('menu_lib.php');

function menu_footer() {
    print '</body></html>';
}

// display the search form
readfile('input.html');

// assign the user-supplied input to a local variable
if (!isset($_POST['itemName']) or
    !isset($_POST['itemDescription']) or
    !isset($_POST['price'])) {
    print "To add a new menu item, please fill out all three fields.";
    print menu_footer();
    exit;
}

$endScript = false;

// you can filter the input here
$name = preg_match('#^[^\W_]+$#', $_POST['itemName']);
if (!$name) {
    print "The menu name may only contain letters and numbers.";
    $endScript = true;
}
else {
    $name = $_POST['itemName'];
}

$description = preg_match('#^[^\W_]+$#', $_POST['itemDescription']);
if (!$description) {
    print "The item description may only contain letters and numbers.";
    $endScript = true;
}
else {
    $description = $_POST['itemDescription'];
}

$price = preg_match('#^[\d]{0,3}\.?[\d]{0,2}$#', $_POST['price']);
if (!$price) {
    print "The item price may only contain a decimal.";
    $endScript = true;
}
else {
    $price = $_POST['price'];
}

if ($endScript) {
  print menu_footer();
  exit;
}

// Create the connection, catching any exceptions
try {
    // connect with default parameter values
    $conn = menu_connect();
}
catch (PDOException $e) {
    print "Failed to connect: " . $e->getMessage();
    exit;
}

// Use parameter markers to support variable input
$sql_food = 'INSERT INTO menu.food(name, description)
  VALUES (:name, :description)';
$sql_price = 'INSERT INTO menu.prices (id, price)
  VALUES (IDENTITY_VAL_LOCAL(), :price)';

// Prepare the statement
$stmt_food = $conn->prepare($sql_food);
$stmt_price = $conn->prepare($sql_price);

try {
    // Begin a transaction
    $conn->beginTransaction();

    // Execute the statement, passing in an array of input variables
    $stmt_food->execute(array(':name' => $name, ':description' => $description));

    // Execute the statement, passing in an array of input variables
    $stmt_price->execute(array(':price' => $price));
}
catch (PDOException $e) {
    // Uh-oh -- roll back the transaction
    $conn->rollBack();
    print menu_footer();
    exit();
}

// Commit the transaction
$conn->commit();

$stmt = null;
$conn = null;

print menu_footer();

?>
