#!/usr/bin/perl
use strict;
use warnings;
use DBI;
use CGI;

# Instantiate a new CGI object
my $query = new CGI;

# Print the HTTP header
print $query->header();

# Print our HTML header and search form
print header('Search for a menu item');

# Declare the $search variable in the global scope
my $search;

# Ensure the requested CGI parameter actually exists
if ($query->param('search')) {
	# Whitelist filter the input string to prevent naughty input
	($search) = $query->param('search') =~ m/^([^\W_]+)$/;
}

if (!$search) {
	print "Please enter an alphanumeric search string.";
	exit;
}

# Connect to the database
my $conn = db_connect();

# Declare the SELECT statement
my $sql = q{SELECT name, description
	FROM menu.food
	WHERE name LIKE ?};

# Prepare the SELECT statement
# Apache Derby will return an error if the prepare fails.
my $sth = $conn->prepare($sql);

# Pass in the value for the query placeholder
# For multiple values in a single statement, you can pass an array
my $result = $sth->execute($search);

# Declare the variables to which the columns will be bound
my ($name, $description);

# Bind the variables to the returned columns
$result = $sth->bind_columns(\$name, \$description);

# Loop through each row
while ($sth->fetch) {
	print "<p>Name: $name <br />Description: $description</p>\n";
}

sub db_connect {
	my $database = 'MYDB';
	my $user = 'lynn';
	my $password = '5tuff';
	my $hostname = 'localhost';
	my $port = 1527;

	# Create the connection string for an uncataloged connection
	my $DSN = "DRIVER={IBM DB2 ODBC DRIVER};DATABASE=$database;"
		. "HOSTNAME=$hostname;PORT=$port;PROTOCOL=TCPIP;";

	my $conn = DBI->connect("dbi:DB2:$DSN", $user, $password,
	{ AutoCommit => 1, PrintError => 0 } );
	return $conn;
}

sub header {
	my ($title) = @_;
	my $header = "<html>
<head><title>$title</title></head>
<body><h1>$title</h1>";

	$header .= q{
<form action='search.pl' method='POST'>
<label for='sinput'>Please enter the search string:</label>
<input type='text' name='search' id='sinput' size='30'/><br />
<input type='submit'/><input type='reset'/>
</form>
	};

	return $header;
}
