#!/usr/bin/perl
use strict;
use warnings;
use DBI;
use CGI;
use mydb qw/ db_connect header footer /;

my $cgi = new CGI;
print $cgi->header();
print header('Insert a new menu item...');
print insert_form();

# Declare variables for forms
my ($itemName, $itemDescription, $price);
if ($cgi->param('itemName')) {
  # Whitelist filter the input string to prevent naughty input
  ($itemName) = $cgi->param('itemName') =~ m/^([^\W_]+)$/;
}
if ($cgi->param('itemDescription')) {
  # Whitelist filter the input string to prevent naughty input
  ($itemDescription) = $cgi->param('itemDescription') =~ m/^([^\W_]+)$/;
}
if ($cgi->param('price')) {
  # Whitelist filter the input string to prevent naughty input
  ($price) = $cgi->param('price') =~ m/^(\d{0,3}\.\d{0,2})$/;
}

if (!$itemName or !$itemDescription or !$price) {
  print "Please enter values for all fields.";
  print footer();
  exit();
}

my $conn = db_connect();

# Throw an exception if an error occurs
$conn->{RaiseError} = 1;

eval {
  # Begin a new transaction
  $conn->begin_work();

  my $food_sql = q{
    INSERT INTO menu.food (name, description)
    VALUES (?, ?)
  };

  my $price_sql = q{
    INSERT INTO menu.prices (id, price)
    VALUES (IDENTITY_VAL_LOCAL(), ?)
  };

  # Prepare the SQL statements
  my $food_stmt = $conn->prepare($food_sql);
  my $price_stmt = $conn->prepare($price_sql);

  # Execute the SQL statements
  $food_stmt->execute($itemName, $itemDescription);
  $price_stmt->execute($price);
};

# Check for errors
if ($@) {
  print "Failed to insert menu item; rolling back the transaction.";
  print "The error was " . $@;
  $conn->rollback();
}
else {
  print "Successfully inserted new menu item.";
  $conn->commit();
}

print footer();
exit();

sub insert_form {
  return "
    <form action='insert_data.pl' method='POST'>
    <label for='name'>Name:</label>
    <input type='text' name='itemName' id='name' size='30'/><br />
    <label for='description'>Description:</label>
    <input type='text' name='itemDescription' id='description' size='30'/><br />
    <label for='price'>Price:</label>
    <input type='text' name='price' id='price' size='6'/><br />
    <input type='submit'/><input type='reset'/>
    </form>
  ";
}



